return {
	{
		"hrsh7th/nvim-cmp",
		event = "InsertEnter",
		dependencies = {
			"hrsh7th/cmp-buffer", -- source for text in buffer
			"hrsh7th/cmp-path", -- source for file system paths
			{
				"L3MON4D3/LuaSnip",
				version = "v2.*", -- latest release of LuaSnip
				build = "make install_jsregexp", -- optional regex support for LuaSnip
			},
			"saadparwaiz1/cmp_luasnip", -- for autocompletion
			"rafamadriz/friendly-snippets", -- useful snippets
			"onsails/lspkind.nvim", -- vs-code like pictograms
		},
		config = function()
			local cmp = require("cmp")
			local luasnip = require("luasnip")
			local lspkind = require("lspkind")

			-- Load snippets from friendly-snippets and custom directory
			require("luasnip.loaders.from_vscode").lazy_load()
			require("luasnip.loaders.from_vscode").lazy_load({ paths = { "~/.config/nvim/snippets" } })

			cmp.setup({
				completion = {
					completeopt = "menu,menuone,preview,noselect",
				},
				snippet = {
					expand = function(args)
						luasnip.lsp_expand(args.body)
					end,
				},
				mapping = cmp.mapping.preset.insert({
					-- ["<C-x>"] = cmp.mapping({
					-- 	cmp.mapping.complete({
					-- 		config = {
					-- 			sources = cmp.config.sources({
					-- 				{ name = "cmp_ai" },
					-- 			}),
					-- 		},
					-- 	}),
					-- 	{ "i" },
					-- }),

					["<C-k>"] = cmp.mapping.select_prev_item(), -- previous suggestion
					["<C-j>"] = cmp.mapping.select_next_item(), -- next suggestion
					["<C-b>"] = cmp.mapping.scroll_docs(-4),
					["<C-f>"] = cmp.mapping.scroll_docs(4),
					["<C-Space>"] = cmp.mapping.complete(), -- show completion suggestions
					["<C-e>"] = cmp.mapping.abort(), -- close completion window
					["<CR>"] = cmp.mapping.confirm({ select = false }),

					-- Tab to complete
					["<Tab>"] = cmp.mapping(function(fallback)
						if cmp.visible() then
							cmp.confirm({ select = true }) -- confirm selection
						elseif luasnip.expand_or_jumpable() then
							luasnip.expand_or_jump()
						else
							fallback()
						end
					end, { "i", "s" }),
				}),
				-- sources for autocompletion
				sources = cmp.config.sources({
					{ name = "nvim_lsp" },
					{ name = "luasnip" }, -- snippets
					{ name = "buffer" }, -- text within current buffer
					{ name = "path" }, -- file system paths
					-- { name = "cmp_ai" }, -- AI completion
				}),
				-- configure lspkind for vs-code like pictograms in completion menu
				formatting = {
					format = lspkind.cmp_format({
						mode = "symbol_text", -- show symbol text with icons
						maxwidth = 130,
						ellipsis_char = "...",
					}),
				},
				-- Enable rounded borders
				window = {
					completion = cmp.config.window.bordered(),
					documentation = cmp.config.window.bordered(),
				},
				experimental = {
					ghost_text = true, -- This enables the inline ghost text
				},
			})
		end,
	},

	-- {
	-- 	-- ─< for ai use >──────────────────────────────────────────────────────────────────────
	-- 	"tzachar/cmp-ai",
	-- 	dependencies = {
	-- 		"hrsh7th/nvim-cmp",
	-- 		"tzachar/cmp-ai",
	-- 	},
	--
	-- 	config = function()
	-- 		local cmp = require("cmp")
	-- 		local cmp_ai = require("cmp_ai.config")
	--
	-- 		-- Setup cmp-ai configuration
	-- 		cmp_ai:setup({
	-- 			max_lines = 100,
	-- 			provider = "Ollama",
	-- 			-- provider_options = {
	-- 			-- 	model = "codellama:7b-code",
	-- 			-- 	auto_unload = false,
	-- 			-- 	raw_response_cb = function(response)
	-- 			-- 		vim.notify(vim.inspect(response))
	-- 			-- 		vim.g.ai_raw_response = response
	-- 			-- 	end,
	-- 			-- },
	-- 			provider_options = {
	-- 				model = "qwen2.5-coder:7b-base-q6_K",
	-- 				prompt = function(lines_before, lines_after)
	-- 					return "<|fim_prefix|>" .. lines_before .. "<|fim_suffix|>" .. lines_after .. "<|fim_middle|>"
	-- 				end,
	-- 				raw_response_cb = function(response)
	-- 					vim.notify(vim.inspect(response))
	-- 					vim.g.ai_raw_response = response
	-- 				end,
	-- 			},
	-- 			notify = true,
	-- 			notify_callback = function(msg)
	-- 				vim.notify(msg)
	-- 			end,
	-- 			run_on_every_keystroke = true,
	-- 			ignored_file_types = {
	-- 				txt = true,
	-- 			},
	-- 		})
	-- 	end,
	-- },
}
